# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['FrontdoorRouteDisableLinkToDefaultDomainArgs', 'FrontdoorRouteDisableLinkToDefaultDomain']

@pulumi.input_type
class FrontdoorRouteDisableLinkToDefaultDomainArgs:
    def __init__(__self__, *,
                 cdn_frontdoor_custom_domain_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 cdn_frontdoor_route_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a FrontdoorRouteDisableLinkToDefaultDomain resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cdn_frontdoor_custom_domain_ids: The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        :param pulumi.Input[str] cdn_frontdoor_route_id: The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        if cdn_frontdoor_custom_domain_ids is not None:
            warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
            pulumi.log.warn("""cdn_frontdoor_custom_domain_ids is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
        pulumi.set(__self__, "cdn_frontdoor_custom_domain_ids", cdn_frontdoor_custom_domain_ids)
        if cdn_frontdoor_route_id is not None:
            warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
            pulumi.log.warn("""cdn_frontdoor_route_id is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
        pulumi.set(__self__, "cdn_frontdoor_route_id", cdn_frontdoor_route_id)

    @property
    @pulumi.getter(name="cdnFrontdoorCustomDomainIds")
    def cdn_frontdoor_custom_domain_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_custom_domain_ids")

    @cdn_frontdoor_custom_domain_ids.setter
    def cdn_frontdoor_custom_domain_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "cdn_frontdoor_custom_domain_ids", value)

    @property
    @pulumi.getter(name="cdnFrontdoorRouteId")
    def cdn_frontdoor_route_id(self) -> pulumi.Input[str]:
        """
        The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_route_id")

    @cdn_frontdoor_route_id.setter
    def cdn_frontdoor_route_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cdn_frontdoor_route_id", value)


@pulumi.input_type
class _FrontdoorRouteDisableLinkToDefaultDomainState:
    def __init__(__self__, *,
                 cdn_frontdoor_custom_domain_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cdn_frontdoor_route_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FrontdoorRouteDisableLinkToDefaultDomain resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cdn_frontdoor_custom_domain_ids: The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        :param pulumi.Input[str] cdn_frontdoor_route_id: The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        if cdn_frontdoor_custom_domain_ids is not None:
            warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
            pulumi.log.warn("""cdn_frontdoor_custom_domain_ids is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
        if cdn_frontdoor_custom_domain_ids is not None:
            pulumi.set(__self__, "cdn_frontdoor_custom_domain_ids", cdn_frontdoor_custom_domain_ids)
        if cdn_frontdoor_route_id is not None:
            warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
            pulumi.log.warn("""cdn_frontdoor_route_id is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
        if cdn_frontdoor_route_id is not None:
            pulumi.set(__self__, "cdn_frontdoor_route_id", cdn_frontdoor_route_id)

    @property
    @pulumi.getter(name="cdnFrontdoorCustomDomainIds")
    def cdn_frontdoor_custom_domain_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_custom_domain_ids")

    @cdn_frontdoor_custom_domain_ids.setter
    def cdn_frontdoor_custom_domain_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "cdn_frontdoor_custom_domain_ids", value)

    @property
    @pulumi.getter(name="cdnFrontdoorRouteId")
    def cdn_frontdoor_route_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_route_id")

    @cdn_frontdoor_route_id.setter
    def cdn_frontdoor_route_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn_frontdoor_route_id", value)


class FrontdoorRouteDisableLinkToDefaultDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cdn_frontdoor_custom_domain_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cdn_frontdoor_route_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages the Link To Default Domain property of a Front Door (standard/premium) Route.

        !>**IMPORTANT:** This resource has been deprecated and should not be used for new deployments. The `cdn.FrontdoorRouteDisableLinkToDefaultDomain` resource will be removed from the 4.0 AzureRM provider. Please use the `link_to_default_domain` field in the `cdn.FrontdoorRoute` resource to control this value.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.cdn.FrontdoorRouteDisableLinkToDefaultDomain("example",
            cdn_frontdoor_route_id=azurerm_cdn_frontdoor_route["example"]["id"],
            cdn_frontdoor_custom_domain_ids=[
                azurerm_cdn_frontdoor_custom_domain["contoso"]["id"],
                azurerm_cdn_frontdoor_custom_domain["fabrikam"]["id"],
            ])
        ```

        ## Import

        FrontDoor Route Disable Link To Default Domain can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:cdn/frontdoorRouteDisableLinkToDefaultDomain:FrontdoorRouteDisableLinkToDefaultDomain example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.Cdn/profiles/profile1/afdEndpoints/endpoint1/routes/route1/disableLinkToDefaultDomain/disableLinkToDefaultDomain1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cdn_frontdoor_custom_domain_ids: The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        :param pulumi.Input[str] cdn_frontdoor_route_id: The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FrontdoorRouteDisableLinkToDefaultDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the Link To Default Domain property of a Front Door (standard/premium) Route.

        !>**IMPORTANT:** This resource has been deprecated and should not be used for new deployments. The `cdn.FrontdoorRouteDisableLinkToDefaultDomain` resource will be removed from the 4.0 AzureRM provider. Please use the `link_to_default_domain` field in the `cdn.FrontdoorRoute` resource to control this value.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.cdn.FrontdoorRouteDisableLinkToDefaultDomain("example",
            cdn_frontdoor_route_id=azurerm_cdn_frontdoor_route["example"]["id"],
            cdn_frontdoor_custom_domain_ids=[
                azurerm_cdn_frontdoor_custom_domain["contoso"]["id"],
                azurerm_cdn_frontdoor_custom_domain["fabrikam"]["id"],
            ])
        ```

        ## Import

        FrontDoor Route Disable Link To Default Domain can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:cdn/frontdoorRouteDisableLinkToDefaultDomain:FrontdoorRouteDisableLinkToDefaultDomain example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.Cdn/profiles/profile1/afdEndpoints/endpoint1/routes/route1/disableLinkToDefaultDomain/disableLinkToDefaultDomain1
        ```

        :param str resource_name: The name of the resource.
        :param FrontdoorRouteDisableLinkToDefaultDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FrontdoorRouteDisableLinkToDefaultDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cdn_frontdoor_custom_domain_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cdn_frontdoor_route_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FrontdoorRouteDisableLinkToDefaultDomainArgs.__new__(FrontdoorRouteDisableLinkToDefaultDomainArgs)

            if cdn_frontdoor_custom_domain_ids is None and not opts.urn:
                raise TypeError("Missing required property 'cdn_frontdoor_custom_domain_ids'")
            if cdn_frontdoor_custom_domain_ids is not None and not opts.urn:
                warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
                pulumi.log.warn("""cdn_frontdoor_custom_domain_ids is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
            __props__.__dict__["cdn_frontdoor_custom_domain_ids"] = cdn_frontdoor_custom_domain_ids
            if cdn_frontdoor_route_id is None and not opts.urn:
                raise TypeError("Missing required property 'cdn_frontdoor_route_id'")
            if cdn_frontdoor_route_id is not None and not opts.urn:
                warnings.warn("""the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""", DeprecationWarning)
                pulumi.log.warn("""cdn_frontdoor_route_id is deprecated: the 'cdn_frontdoor_route_disable_link_to_default_domain' resource has been deprecated and will be removed from the 4.0 AzureRM provider. Please use the 'link_to_default_domain' field in the 'cdn_frontdoor_route' resource to control this value""")
            __props__.__dict__["cdn_frontdoor_route_id"] = cdn_frontdoor_route_id
        super(FrontdoorRouteDisableLinkToDefaultDomain, __self__).__init__(
            'azure:cdn/frontdoorRouteDisableLinkToDefaultDomain:FrontdoorRouteDisableLinkToDefaultDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cdn_frontdoor_custom_domain_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cdn_frontdoor_route_id: Optional[pulumi.Input[str]] = None) -> 'FrontdoorRouteDisableLinkToDefaultDomain':
        """
        Get an existing FrontdoorRouteDisableLinkToDefaultDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] cdn_frontdoor_custom_domain_ids: The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        :param pulumi.Input[str] cdn_frontdoor_route_id: The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FrontdoorRouteDisableLinkToDefaultDomainState.__new__(_FrontdoorRouteDisableLinkToDefaultDomainState)

        __props__.__dict__["cdn_frontdoor_custom_domain_ids"] = cdn_frontdoor_custom_domain_ids
        __props__.__dict__["cdn_frontdoor_route_id"] = cdn_frontdoor_route_id
        return FrontdoorRouteDisableLinkToDefaultDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cdnFrontdoorCustomDomainIds")
    def cdn_frontdoor_custom_domain_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        The resource IDs of the Front Door Custom Domains which are associated with this Front Door Route. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_custom_domain_ids")

    @property
    @pulumi.getter(name="cdnFrontdoorRouteId")
    def cdn_frontdoor_route_id(self) -> pulumi.Output[str]:
        """
        The resource ID of the Front Door Route where the Link To Default Domain property should be `disabled`. Changing this forces a new Front Door Route Disable Link To Default Domain to be created.
        """
        return pulumi.get(self, "cdn_frontdoor_route_id")

